/**
 * @file
 * Adds a behavior for initializing the Slick slideshows.
 */
(function($) {
  // Store slideshow settings.
  var slickSlideshowSettings = Drupal.settings.slickSlideshowSettings;
  var target = '';

  // Initialize the slick sliders.
  Drupal.behaviors.slickSlideshowBehavior = {
    attach: function (context, settings) {
      $.each(slickSlideshowSettings, function(fieldSelector, settings) {
        if (fieldSelector.charAt(0) !== '#' && fieldSelector.charAt(0) !== '.') {
          // Selector fallback to id if only the selector name is passed.
          fieldSelector = '#' + fieldSelector;
        }

        var field = $(fieldSelector, context);
        field.once('slickSlideshowBehavior', function() {
          var fieldSettings = settings['settings'];

          // Change settings passed as strings to correct data type.
          for (var key in fieldSettings) {
            var field = fieldSettings[key];
            if (typeof field === 'string') {
              // Change string to Function.
              if (field.indexOf('function(') === 0) {
                var params = field.between('function(', ')');
                var functionBody = field.between('{', '}');
                fieldSettings[key] = new Function(params, functionBody);
              }
              // Change string to Object.
              if (field.indexOf('[') === 0 || field.indexOf('{') === 0) {
                if (field.between('[', ']') || field.between('{', '}')) {
                  fieldSettings[key] = eval(field);
                }
              }
            }
          }

          if (settings['target']) {
            // Check to see if there's a child target to initialize slick on.
            target = $(this).find(settings['target']).first();
          } else {
            // Initialize Slick directly on element with id.
            target = this;
          }

          // Initialize Slick.
          $(target).slick(fieldSettings);
        });
      });
    }
  };
}(jQuery));

/*
 * Function that grabs substring between two specified substrings.
 */
String.prototype.between = function(prefix, suffix) {
  s = this;
  var i = s.indexOf(prefix);
  if (i >= 0) {
    s = s.substring(i + prefix.length);
  }
  else {
    return '';
  }
  if (suffix) {
    i = s.indexOf(suffix);
    if (i >= 0) {
      s = s.substring(0, i);
    }
    else {
      return '';
    }
  }
  return s;
}
